.. image:: https://travis-ci.org/ambitioninc/django-kmatch.png
   :target: https://travis-ci.org/ambitioninc/django-kmatch


django-kmatch - Django utilities for kmatch
===========================================

The django-kmatch app provides various utilities around the `Python kmatch library`_. 

.. _Python kmatch library: https://github.com/ambitioninc/kmatch

This app currently provides the following:

1. A ``KField`` model field that allows the user to store a kmatch pattern and access it as a ``K`` object.


Installation
------------
To install the latest release, type::

    pip install django-kmatch

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-kmatch.git

Documentation
-------------

Full documentation is available at http://django-kmatch.readthedocs.org

License
-------
MIT License (see LICENSE)